@@ -100,6 +100,7 @@ class Script:
         self.brailleGenerator = self.getBrailleGenerator()
         self.speechGenerator = self.getSpeechGenerator()
         self.generatorCache = {}
+        self.eventCache = {}
         self.whereAmI = self.getWhereAmI()
         self.bookmarks = self.getBookmarks()
         self.voices = settings.voices
@@ -325,6 +326,26 @@ class Script:
 
         return orca_state.clickCount
 
+    def getSettings(self):
+        """Returns the settings associated with this script, regardless of
+        whether or not the script is active.
+        """
+
+        scriptSettings = settings
+        if orca_state.activeScript != self:
+            name = settings.getScriptModuleName(self.app)
+            if name:
+                for package in settings.settingsPackages:
+                    name = package + "." + name
+                    try:
+                        module = __import__(name, globals(), locals(), [''])
+                        reload(module)
+                        scriptSettings = module.orca.settings
+                    except:
+                        pass
+
+        return scriptSettings
+
     # [[[WDW - There is a circular reference going on somewhere (see
     # bug 333168).  In the presence of this reference, the existence
     # of a __del__ method prevents the garbage collector from
@@ -364,6 +385,9 @@ class Script:
         if not processEvent:
             return
 
+        if self.skipObjectEvent(event):
+            return
+
         # Clear the generator cache for each event.
         #
         self.generatorCache = {}
@@ -382,6 +406,42 @@ class Script:
             if event.type.startswith(key):
                 self.listeners[key](event)
 
+    def skipObjectEvent(self, event):
+        """Gives us, and scripts, the ability to decide an event isn't
+        worth taking the time to process under the current circumstances.
+
+        Arguments:
+        - event: the Event
+
+        Returns True if we shouldn't bother processing this object event.
+        """
+
+        cachedEvent, eventTime = self.eventCache.get(event.type, [None, 0])
+        if not cachedEvent or cachedEvent == event:
+            return False
+
+        focus    = ["focus:", "object:state-changed:focused"]
+        typing   = ["object:text-changed:insert", "object:text-changed:delete"]
+        arrowing = ["object:text-caret-moved", "object:text-selection-changed",
+                    "object:selection-changed"]
+
+        skip = False
+        if (event.type in arrowing or event.type in typing) \
+           and event.source == cachedEvent.source:
+            skip = True
+            reason = "more recent event of the same type in the same object"
+        elif event.type in focus and event.source != cachedEvent.source \
+             and event.detail1 == cachedEvent.detail1:
+            skip = True
+            reason = "more recent event of the same type in a different object"
+
+        if skip:
+            debug.println(debug.LEVEL_FINE,
+                          "script.skipObjectEvent: skipped due to %s" \
+                          % reason)
+
+        return skip
+
     def checkKeyboardEventData(self, keyboardEvent):
         """Checks the data on the keyboard event.
 
